@@ -75,12 +75,54 @@ pub const kSSLStreamType: SSLConnectionType = 0;
 pub const kSSLDatagramType: SSLConnectionType = 1;
 
 pub const errSSLProtocol: OSStatus = -9800;
+pub const errSSLNegotiation: OSStatus = -9801;
+pub const errSSLFatalAlert: OSStatus = -9802;
 pub const errSSLWouldBlock: OSStatus = -9803;
+pub const errSSLSessionNotFound: OSStatus = -9804;
 pub const errSSLClosedGraceful: OSStatus = -9805;
 pub const errSSLClosedAbort: OSStatus = -9806;
+pub const errSSLXCertChainInvalid: OSStatus = -9807;
+pub const errSSLBadCert: OSStatus = -9808;
+pub const errSSLCrypto: OSStatus = -9809;
+pub const errSSLInternal: OSStatus = -9810;
+pub const errSSLModuleAttach: OSStatus = -9811;
+pub const errSSLUnknownRootCert: OSStatus = -9812;
+pub const errSSLNoRootCert: OSStatus = -9813;
+pub const errSSLCertExpired: OSStatus = -9814;
+pub const errSSLCertNotYetValid: OSStatus = -9815;
 pub const errSSLClosedNoNotify: OSStatus = -9816;
+pub const errSSLBufferOverflow: OSStatus = -9817;
+pub const errSSLBadCipherSuite: OSStatus = -9818;
+pub const errSSLPeerUnexpectedMsg: OSStatus = -9819;
+pub const errSSLPeerBadRecordMac: OSStatus = -9820;
+pub const errSSLPeerDecryptionFail: OSStatus = -9821;
+pub const errSSLPeerRecordOverflow: OSStatus = -9822;
+pub const errSSLPeerDecompressFail: OSStatus = -9823;
+pub const errSSLPeerHandshakeFail: OSStatus = -9824;
+pub const errSSLPeerBadCert: OSStatus = -9825;
+pub const errSSLPeerUnsupportedCert: OSStatus = -9826;
+pub const errSSLPeerCertRevoked: OSStatus = -9827;
+pub const errSSLPeerCertExpired: OSStatus = -9828;
+pub const errSSLPeerCertUnknown: OSStatus = -9829;
+pub const errSSLIllegalParam: OSStatus = -9830;
+pub const errSSLPeerUnknownCA: OSStatus = -9831;
+pub const errSSLPeerAccessDenied: OSStatus = -9832;
+pub const errSSLPeerDecodeError: OSStatus = -9833;
+pub const errSSLPeerDecryptError: OSStatus = -9834;
+pub const errSSLPeerExportRestriction: OSStatus = -9835;
+pub const errSSLPeerProtocolVersion: OSStatus = -9836;
+pub const errSSLPeerInsufficientSecurity: OSStatus = -9837;
+pub const errSSLPeerInternalError: OSStatus = -9838;
+pub const errSSLPeerUserCancelled: OSStatus = -9839;
+pub const errSSLPeerNoRenegotiation: OSStatus = -9840;
 pub const errSSLPeerAuthCompleted: OSStatus = -9841;
 pub const errSSLClientCertRequested: OSStatus = -9842;
+pub const errSSLHostNameMismatch: OSStatus = -9843;
+pub const errSSLConnectionRefused: OSStatus = -9844;
+pub const errSSLDecryptionFail: OSStatus = -9845;
+pub const errSSLBadRecordMac: OSStatus = -9846;
+pub const errSSLRecordOverflow: OSStatus = -9847;
+pub const errSSLBadConfiguration: OSStatus = -9848;
 pub const errSSLClientHelloReceived: OSStatus = -9851;
 
 pub type SSLAuthenticate = c_int;
